"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const requirements_1 = require("../../requirements");
const chalk = require('chalk');
const execa = require('execa');
const Listr = require('listr');
const semver = require('semver');
class LmInfo extends command_1.Command {
    async run() {
        const steps = requirements_1.GitValidators;
        steps.push({
            title: 'Checking Git LFS filters',
            task: async () => {
                const installed = await requirements_1.checkLFSFilters();
                if (!installed) {
                    throw new Error('Git LFS filters are not installed, run `git lfs install` to install them');
                }
            }
        }, {
            title: `Checking Netlify's Git Credentials version`,
            task: async (ctx, task) => {
                const version = await requirements_1.checkHelperVersion();
                task.title += chalk.dim(` [${version}]`);
            }
        });
        const tasks = new Listr(steps, { concurrent: true, exitOnError: false });
        tasks.run().catch((err) => { });
    }
}
LmInfo.description = 'Netlify Large Media';
LmInfo.examples = ['$ <%- config.bin %> lm:info'];
LmInfo.usage = 'lm:info';
exports.default = LmInfo;
